@@ -6,17 +6,12 @@ namespace Doctrine\Tests\ORM\Functional\Ticket;
 
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 
 use function get_class;
 
-/**
- * @group DDC-1594
- */
+/** @group DDC-1594 */
 class DDC1594Test extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $this->useModelSet('cms');
@@ -42,9 +37,8 @@ class DDC1594Test extends OrmFunctionalTestCase
 
         $mergedUser = $this->_em->merge($detachedUser);
 
-        $this->assertNotSame($mergedUser, $detachedUser);
-        $this->assertEquals('bar', $detachedUser->getName());
-        $this->assertEquals('bar', $mergedUser->getName());
-        $this->assertHasDeprecationMessages();
+        self::assertNotSame($mergedUser, $detachedUser);
+        self::assertEquals('bar', $detachedUser->getName());
+        self::assertEquals('bar', $mergedUser->getName());
     }
 }
